aboutsummaryrefslogtreecommitdiffstats
path: root/src/audio_parser.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/audio_parser.h')
-rw-r--r--src/audio_parser.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/audio_parser.h b/src/audio_parser.h
index 30a927456..d50c17489 100644
--- a/src/audio_parser.h
+++ b/src/audio_parser.h
@@ -37,11 +37,13 @@ struct audio_format;
*
* @param dest the destination #audio_format struct
* @param src the input string
* @param error location to store the error occuring, or NULL to
* ignore errors
* @return true on success
*/
bool
-audio_format_parse(struct audio_format *dest, const char *src, GError **error);
+audio_format_parse(struct audio_format *dest, const char *src,
+ bool mask, GError **error_r);
#endif
@@ -37,11 +37,13 @@ struct audio_format;
* @param dest the destination #audio_format struct
* @param src the input string
- * @param error location to store the error occuring, or NULL to
+ * @param mask if true, then "*" is allowed for any number of items
+ * @param error_r location to store the error occuring, or NULL to
* ignore errors
* @return true on success